==> haskell-ghc-tcplugins-extra-0.3.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-tcplugins-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-tcplugins-extra
version:              0.3.1
visibility:           public
id:                   ghc-tcplugins-extra-0.3.1-52N3nlccyadJut1vhNa8PD
key:                  ghc-tcplugins-extra-0.3.1-52N3nlccyadJut1vhNa8PD
license:              BSD-2-Clause
copyright:
    Copyright © 2015-2016, University of Twente,
    2017-2018, QBayLogic

maintainer:           christiaan.baaij@gmail.com
author:               Christiaan Baaij
homepage:             http://github.com/clash-lang/ghc-tcplugins-extra
synopsis:             Utilities for writing GHC type-checker plugins
description:
    Utilities for writing GHC type-checker plugins, such as
    creating constraints, with a stable API covering multiple
    GHC releases.

category:             Type System
abi:                  ccb5b402f8c99bcebe5b8896299f4c6e
exposed:              True
exposed-modules:      GHC.TcPluginM.Extra
import-dirs:          /usr/lib/ghc-8.8.3/site-local/ghc-tcplugins-extra-0.3.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/ghc-tcplugins-extra-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/ghc-tcplugins-extra-0.3.1
hs-libraries:         HSghc-tcplugins-extra-0.3.1-52N3nlccyadJut1vhNa8PD
depends:              base-4.13.0.0 ghc-8.8.3
haddock-interfaces:
    /usr/share/doc/haskell-ghc-tcplugins-extra/html/ghc-tcplugins-extra.haddock

haddock-html:         /usr/share/doc/haskell-ghc-tcplugins-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-tcplugins-extra-0.3.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-tcplugins-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-tcplugins-extra
version:              0.3.2
visibility:           public
id:                   ghc-tcplugins-extra-0.3.2-GsNmygbk7NUGCrqSFBjpGw
key:                  ghc-tcplugins-extra-0.3.2-GsNmygbk7NUGCrqSFBjpGw
license:              BSD-2-Clause
copyright:
    Copyright © 2015-2016, University of Twente,
    2017-2018, QBayLogic

maintainer:           christiaan.baaij@gmail.com
author:               Christiaan Baaij
homepage:             http://github.com/clash-lang/ghc-tcplugins-extra
synopsis:             Utilities for writing GHC type-checker plugins
description:
    Utilities for writing GHC type-checker plugins, such as
    creating constraints, with a stable API covering multiple
    GHC releases.

category:             Type System
abi:                  5524ec25ca5ff8d736448e6124bcc02c
exposed:              True
exposed-modules:      GHC.TcPluginM.Extra
import-dirs:          /usr/lib/ghc-8.8.3/site-local/ghc-tcplugins-extra-0.3.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/ghc-tcplugins-extra-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/ghc-tcplugins-extra-0.3.2
hs-libraries:         HSghc-tcplugins-extra-0.3.2-GsNmygbk7NUGCrqSFBjpGw
depends:              base-4.13.0.0 ghc-8.8.3
haddock-interfaces:
    /usr/share/doc/haskell-ghc-tcplugins-extra/html/ghc-tcplugins-extra.haddock

haddock-html:         /usr/share/doc/haskell-ghc-tcplugins-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
